Store the SEC user agent for this session and optionally future sessions
dera_set_user_agent.RdStore the SEC user agent for this session and optionally future sessions
Usage
dera_set_user_agent(
user_agent,
save = interactive(),
renviron = file.path(path.expand("~"), ".Renviron")
)