Skip to contents

Downloads new or changed SEC DERA Financial Statement Data Set zip files and writes sub, tag, num, and pre Parquet files under $DATA_DIR/dera.

Usage

update_dera(
  data_dir = NULL,
  user_agent = NULL,
  quiet = FALSE,
  cache = TRUE,
  force = FALSE
)

Arguments

data_dir

Root of the local Parquet repository. If omitted, resolved using dera_data_dir().

user_agent

Optional SEC-compliant user agent. If omitted, resolved using dera_user_agent().

quiet

If TRUE, suppress progress messages.

cache

If TRUE, cache downloaded zip files under tools::R_user_dir("dera.pq", "cache"). If a string, use that directory as the zip cache. If FALSE, download to a temporary file and delete it after processing.

force

If TRUE, reprocess all SEC source zip files listed by the SEC even when the local Parquet files already appear current.

Value

Invisibly, a tibble of source zip files that were updated.