Update SEC DERA Financial Statement Data Set Parquet files
update_dera.RdDownloads new or changed SEC DERA Financial Statement Data Set zip files and
writes sub, tag, num, and pre Parquet files under $DATA_DIR/dera.
Arguments
- data_dir
Root of the local Parquet repository. If omitted, resolved using
dera_data_dir().- user_agent
Optional SEC-compliant user agent. If omitted, resolved using
dera_user_agent().- quiet
If
TRUE, suppress progress messages.- cache
If
TRUE, cache downloaded zip files undertools::R_user_dir("dera.pq", "cache"). If a string, use that directory as the zip cache. IfFALSE, download to a temporary file and delete it after processing.- force
If
TRUE, reprocess all SEC source zip files listed by the SEC even when the local Parquet files already appear current.